@@ -829,6 +829,33 @@ class ToUfosTestBase(ParametrizedUfoModuleTestMixin):
         ufo = self.to_ufos(font)[0]
         self.assertEqual([l.name for l in ufo.layers], ["public.default", "SubLayer"])
 
+    def test_duplicate_supplementary_layers(self):
+        """Test glyph layers with same name."""
+        font = generate_minimal_font()
+        glyph = GSGlyph(name="a")
+        font.glyphs.append(glyph)
+        layer = GSLayer()
+        layer.layerId = font.masters[0].id
+        layer.width = 0
+        glyph.layers.append(layer)
+        sublayer = GSLayer()
+        sublayer.associatedMasterId = font.masters[0].id
+        sublayer.width = 0
+        sublayer.name = "SubLayer"
+        glyph.layers.append(sublayer)
+        sublayer = GSLayer()
+        sublayer.associatedMasterId = font.masters[0].id
+        sublayer.width = 0
+        sublayer.name = "SubLayer"
+        glyph.layers.append(sublayer)
+        with CapturingLogHandler(builder.logger, level="WARNING") as captor:
+            ufo = self.to_ufos(font)[0]
+
+        self.assertEqual(
+            [l.name for l in ufo.layers], ["public.default", "SubLayer", "SubLayer #1"]
+        )
+        captor.assertRegex("Duplicate glyph layer name")
+
     def test_glyph_lib_Export(self):
         font = generate_minimal_font()
         glyph = add_glyph(font, "a")
@@ -1062,7 +1089,7 @@ class ToUfosTestBase(ParametrizedUfoModuleTestMixin):
         assert master.name == "Thin"
         assert master.weight == "Light"
 
-        ufo, = self.to_ufos(font)
+        (ufo,) = self.to_ufos(font)
         font_rt = to_glyphs([ufo])
         master_rt = font_rt.masters[0]
 
@@ -1084,20 +1111,20 @@ class ToUfosTestBase(ParametrizedUfoModuleTestMixin):
 
     def test_italic_angle(self):
         font = generate_minimal_font()
-        ufo, = self.to_ufos(font)
+        (ufo,) = self.to_ufos(font)
 
         ufo.info.italicAngle = 1
-        ufo_rt, = self.to_ufos(to_glyphs([ufo]))
+        (ufo_rt,) = self.to_ufos(to_glyphs([ufo]))
         assert ufo_rt.info.italicAngle == 1
 
         ufo.info.italicAngle = 1.5
-        ufo_rt, = self.to_ufos(to_glyphs([ufo]))
+        (ufo_rt,) = self.to_ufos(to_glyphs([ufo]))
         assert ufo_rt.info.italicAngle == 1.5
 
         ufo.info.italicAngle = 0
         font_rt = to_glyphs([ufo])
         assert font_rt.masters[0].italicAngle == 0
-        ufo_rt, = self.to_ufos(font_rt)
+        (ufo_rt,) = self.to_ufos(font_rt)
         assert ufo_rt.info.italicAngle == 0
 
     def test_unique_masterid(self):
